%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%	IJMSA class for LaTeX files	 13 January 2021
%%	For any information please send an e-mail to:
%%		jasma@info
%%
%%	Initial class provided by:
%%		Suguru SHIRATORI
%%   Versions:
%%		v1.0 
%%		v1.1  2023/01/21
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% IDENTIFICATION
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{IJMSA}[01/21/2023 IJMSA paper class]

 %% PRELIMINARY DECLARATIONS
\LoadClass[10pt,a4paper]{article}
\RequirePackage[T1]{fontenc}
\RequirePackage[utf8]{inputenc}
\RequirePackage{calc}
\RequirePackage{indentfirst}
\RequirePackage{fancyhdr}
\RequirePackage{graphicx,epstopdf}
\RequirePackage{lastpage}
\RequirePackage{ifthen}
%%%\RequirePackage[displaymath]{lineno}
\RequirePackage{lineno}
\RequirePackage{float}
\RequirePackage[fleqn]{amsmath}
\RequirePackage{amssymb} % For math environment bold format
\RequirePackage{setspace}
\RequirePackage{enumitem}
\RequirePackage{mathpazo}
\RequirePackage{booktabs} % For \toprule etc. in tables
\RequirePackage{titlesec}
\RequirePackage{etoolbox} % For \AtBeginDocument etc.
\RequirePackage{tabto} % To use tab for alignment on first page
\RequirePackage{xcolor, colortbl} % To provide color for soul (for english editing), for adding cell color of table
\RequirePackage{soul} % To highlight text
\newcommand{\highlighting}[1]{\colorbox{yellow}{#1}}
\RequirePackage{multirow}
\RequirePackage{microtype} % For command \textls[]{}
\RequirePackage{tikz} % For \foreach used for Orcid icon
\RequirePackage{totcount} % To enable extracting the value of the counter "page" 
\RequirePackage{changepage} % To adjust the width of the column for the title part
\RequirePackage{attrib} % For XML2PDF use \tag{} for equation
\RequirePackage{upgreek} % For making greek letters not italic
\RequirePackage{array} % For table array
\RequirePackage{tabularx}
\RequirePackage{pbox} % For biography environment
\RequirePackage{ragged2e} % For command \justifying
\RequirePackage{tcolorbox}
\RequirePackage{wrapfig}
\RequirePackage{siunitx}

%%%%%%%%%%%%%%%%%%%%%% OPTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\@continuouspages{}

%%%%% Journal Definition  %%%%%
\gdef\@journal{ijmsa}
\gdef\@journalfull{International Journal of Microgravity Science and Application}
\gdef\@journalshort{Int. J. Microgravity Sci. Appl.}
\gdef\@doiabbr{jasma}
\gdef\@ISSN{2188-9783}
\gdef\@journalURL{https://www.jstage.jst.go.jp/browse/ijmsa/}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%% line numbering %%%%%%%%%%%%%%%%%%%%%%
\let\LN@align\align
\let\LN@endalign\endalign
\renewcommand{\align}{\linenomath\LN@align}
\renewcommand{\endalign}{\LN@endalign\endlinenomath}

\let\LN@gather\gather
\let\LN@endgather\endgather
\renewcommand{\gather}{\linenomath\LN@gather}
\renewcommand{\endgather}{\LN@endgather\endlinenomath}

\let\LN@split\split
\let\LN@endsplit\endsplit
\renewcommand{\split}{\linenomath\LN@split}
\renewcommand{\endsplit}{\LN@endsplit\endlinenomath}

\let\LN@cases\cases
\let\LN@endcases\endcases
\renewcommand{\cases}{\linenomath\LN@cases}
\renewcommand{\endcases}{\LN@endcases\endlinenomath}

\let\LN@equation\equation
\let\LN@endequation\endequation
\renewcommand{\equation}{\linenomath\LN@equation}
\renewcommand{\endequation}{\LN@endequation\endlinenomath}

\let\LN@subequations\subequations
\let\LN@endsubequations\endsubequations
\renewcommand{\subequations}{\linenomath\LN@subequations}
\renewcommand{\endsubequations}{\LN@endsubequations\endlinenomath}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%% To choose the type of manuscript
\DeclareOption{article}{\gdef\@arttype{Article}}
\DeclareOption{review}{\gdef\@arttype{Review}}
\DeclareOption{jasmac}{\gdef\@arttype{JASMAC}}
\DeclareOption{editorial}{\gdef\@arttype{Editorial}}
\DeclareOption{erratum}{\gdef\@arttype{Erratum}}

%% To choose the status of the manuscript
\DeclareOption{submit}{\gdef\@status{submit}}
\DeclareOption{accept}{\gdef\@status{accept}}

%% To choose the whether there is one or more authors
\DeclareOption{oneauthor}{\gdef\@authornum{author}}
\DeclareOption{moreauthors}{\gdef\@authornum{authors}}

%% Add the chosen options to the class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

%% Defaults
\ExecuteOptions{notspecified,10pt,a4paper,article,submit,oneauthor}

%% Process options
\ProcessOptions\relax

%% MORE DECLARATIONS

%%%% Maths environments
\RequirePackage{amsthm}

\renewcommand{\qed}{\unskip\nobreak\quad\qedsymbol} %% This places the symbol right after the text instead of placing it at the end on the line.

\renewenvironment{proof}[1][\proofname]{\par %% \proofname allows to have "Proof of my theorem"
  \pushQED{\qed}%
  \normalfont \topsep6\p@\@plus6\p@\relax
  \trivlist
  \item[\hskip\labelsep
        \bfseries %% "Proof" is bold
    #1\@addpunct{.}]\ignorespaces %% Period instead of colon
}{%
  \popQED\endtrivlist\@endpefalse
}

 \newcounter{theorem}
 \setcounter{theorem}{0}
 \newtheorem{Theorem}[theorem]{Theorem}
 
 \newcounter{lemma}
 \setcounter{lemma}{0}
 \newtheorem{Lemma}[lemma]{Lemma}
 
 \newcounter{corollary}
 \setcounter{corollary}{0}
 \newtheorem{Corollary}[corollary]{Corollary}
 
 \newcounter{proposition}
 \setcounter{proposition}{0}
 \newtheorem{Proposition}[proposition]{Proposition}
 
 \newcounter{characterization}
 \setcounter{characterization}{0}
 \newtheorem{Characterization}[characterization]{Characterization}
 
 \newcounter{property}
 \setcounter{property}{0}
 \newtheorem{Property}[property]{Property}
 
 \newcounter{problem}
 \setcounter{problem}{0}
 \newtheorem{Problem}[problem]{Problem}
 
 \newcounter{example}
 \setcounter{example}{0}
 \newtheorem{Example}[example]{Example}
 
 \newcounter{examplesanddefinitions}
 \setcounter{examplesanddefinitions}{0}
 \newtheorem{ExamplesandDefinitions}[examplesanddefinitions]{Examples and Definitions}
 
 \newcounter{remark}
 \setcounter{remark}{0}
 \newtheorem{Remark}[remark]{Remark}
 
 \newcounter{definition}
 \setcounter{definition}{0}
 \newtheorem{Definition}[definition]{Definition}
 
 \newcounter{hypothesis}
 \setcounter{hypothesis}{0}
 \newtheorem{Hypothesis}[hypothesis]{Hypothesis}

 \newcounter{notation}
 \setcounter{notation}{0}
 \newtheorem{Notation}[notation]{Notation}
 
 \newcounter{assumption}
 \setcounter{assumption}{0}
 \newtheorem{Assumption}[assumption]{Assumption}
 
 % Define left/right mark in math environment
\let\originalleft\left
\let\originalright\right
\renewcommand{\left}{\mathopen{}\mathclose\bgroup\originalleft}
\renewcommand{\right}{\aftergroup\egroup\originalright}
 

%%%% References
\RequirePackage[super,sort&compress]{natbib}

\bibliographystyle{IJMSA}
\bibpunct{}{)}{,}{n}{}{,}%

\renewcommand{\bibnumfmt}[1]{#1)}         %%% [2023/01/18 Shiatori added]

\renewcommand\NAT@set@cites{%
  \ifNAT@numbers
    \ifNAT@super \let\@cite\NAT@citesuper
       \def\NAT@mbox##1{\unskip\nobreak\textsuperscript{##1}}%
       \let\citeyearpar=\citeyear
       \let\NAT@space\relax
       \def\NAT@super@kern{\kern\p@}%
    \else
       \let\NAT@mbox=\mbox
       \let\@cite\NAT@citenum
       \let\NAT@space\relax
       \let\NAT@super@kern\relax
    \fi
    \let\@citex\NAT@citexnum
    \let\@biblabel\NAT@biblabelnum
    \let\@bibsetup\NAT@bibsetnum
    \renewcommand\NAT@idxtxt{\NAT@name\NAT@spacechar\NAT@open\NAT@num\NAT@close}%
    \def\natexlab##1{}%
    \def\NAT@penalty{\penalty\@m}%
  \else
    \let\@cite\NAT@cite
    \let\@citex\NAT@citex
    \let\@biblabel\NAT@biblabel
    \let\@bibsetup\NAT@bibsetup
    \let\NAT@space\NAT@spacechar
    \let\NAT@penalty\@empty
    \renewcommand\NAT@idxtxt{\NAT@name\NAT@spacechar\NAT@open\NAT@date\NAT@close}%
    \def\natexlab##1{##1}%
  \fi}


%%%%% Hyperlinks
%% Define color for citations
\definecolor{bluecite}{HTML}{0875b7}

\RequirePackage[unicode=true,
bookmarksopen={true},
pdffitwindow=true, 
colorlinks=true, 
linkcolor=bluecite, 
citecolor=bluecite, 
urlcolor=bluecite, 
hyperfootnotes=false, 
pdfstartview={FitH},
pdfpagemode= UseNone]{hyperref}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage[capitalize,nameinlink]{cleveref}
\crefdefaultlabelformat{#2\textbf{#1}#3} % <-- Only #1 in \textbf
\crefname{figure}{\textbf{Fig.}}{\textbf{Figs.}}
\Crefname{figure}{\textbf{Figure}}{\textbf{Figures}}
\crefname{table}{\textbf{Table}}{\textbf{Tables}}
\Crefname{table}{\textbf{Table}}{\textbf{Tables}}
\crefname{section}{\textbf{Sec.}}{\textbf{Sections}}
\Crefname{section}{\textbf{Sec.}}{\textbf{Sections}}
\crefname{subsection}{\textbf{Sec.}}{\textbf{Sections}}
\Crefname{subsection}{\textbf{Sec.}}{\textbf{Sections}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% To have the possibility to change the urlcolor
\newcommand{\changeurlcolor}[1]{\hypersetup{urlcolor=#1}} 

%%%% Metadata
\newcommand{\org@maketitle}{}% LATEX-Check
\let\org@maketitle\maketitle
\def\maketitle{%
	\hypersetup{
		pdftitle={\@Title},
		pdfsubject={\@abstract},
		pdfkeywords={\@keyword},
		pdfauthor={\@AuthorNames}
		}%
	\org@maketitle
}

%% tabularxp}N
%ZŒB
\newcolumntype{C}{>{\centering\arraybackslash}X}
%ZŉEB
\newcolumntype{R}{>{\raggedleft\arraybackslash}X}
%ZōB
\newcolumntype{L}{>{\raggedright\arraybackslash}X}

%%%% Footnotes
\RequirePackage{scrextend}
\setlength{\skip\footins}{0.6cm} % Increase space between text and footnote
\setlength{\footnotesep}{10pt} % Increase space between line and footnote
\deffootnote{1.5em}{0em}{\textsuperscript{\thefootnotemark}\quad} % Remove indent


%%%% URL
\RequirePackage{url}
\urlstyle{same}
% Line breaks in URL
\def\UrlDigits{\do\1\do\2\do\3\do\4\do\5\do\6\do\7\do\8\do\9\do\0}
\g@addto@macro{\UrlBreaks}{\UrlOrds}
\g@addto@macro{\UrlBreaks}{\UrlDigits}


%%%% Widows & orphans
\clubpenalty=10000
\widowpenalty=10000
\displaywidowpenalty=10000


%%%% To avoid "Output-loop.." compile bug
\maxdeadcycles=10000



%%%%%% Front matter %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Command for checking for a question mark or exclamation mark in title
\def\instring#1#2{TT\fi\begingroup\edef\x{\endgroup\noexpand\in@{#1}{#2}}\x\ifin@}

\newcommand{\firstargument}{}
\newcommand{\Title}[1]{\gdef\@Title{#1}}%
\def\@TitleCitation{}
\newcommand{\TitleCitation}[1]{\gdef\@TitleCitation{#1}}%
\newcommand{\Author}[1]{\gdef\@Author{#1}}%
\def\@AuthorNames{}
\newcommand{\AuthorNames}[1]{\gdef\@AuthorNames{#1}}%
\def\@AuthorCitation{}
\newcommand{\AuthorCitation}[1]{\gdef\@AuthorCitation{#1}}%
\newcommand{\firstpage}[1]{\gdef\@firstpage{#1}}
\newcommand{\doinum}[1]{\gdef\@doinum{#1}}
\newcommand{\hreflink}[1]{\gdef\@hreflink{#1}}
\newcommand{\papercitation}{%
	\raggedright
	\hyphenpenalty=10000 % Cacel hyphenpent setting for citation
	\tolerance=100
	\@AuthorCitation{} %
	\@TitleCitation. % Remove period if title ends with ? or ! or ...
	\textit{\@journalshort} %
	\textbf{\@pubyear}, %
	\textit{\@pubvolume}, %
	\@articlenumber.
	\changeurlcolor{black}%
	\href{https://doi.org/\@doinum}%
	{\@hreflink}
}


% DOI number


% For \@pubvolume, \@issuenum, and \@articlenumber: create command to cut leading zeros
\newcommand\cutdigits[1]{%
	\ifnum#1>0 %
		\number#1 
	\else
		\ifnum#1<10000 %
			\number#1
		\else             
			error
		\fi
	\fi
}


\newcommand\twodigits[1]{%
	\ifnum#1<10 %
		0\number#1
   	\else
		\number#1
	\fi
}

\doinum{10.15011/\@doiabbr.\@pubvolume.\@pubvolume\twodigits\@issuenum\twodigits\@articlenumber}

\newcommand{\graphicalAbstract}[1]{\gdef\@graphicalAbstract{#1}}

\newcommand{\pubvolume}[1]{\gdef\@pubvolume{\cutdigits{#1}}}
\newcommand{\pubyear}[1]{\gdef\@pubyear{#1}}
\newcommand{\copyrightyear}[1]{\gdef\@copyrightyear{#1}}
\newcommand{\address}[2][]{\renewcommand{\firstargument}{#1}\gdef\@address{#2}}
\newcommand{\corresfirstargument}{}
\def\@corresEmail{}
\def\@coressAddress{}
%%%\newcommand{\corres}[2][]{\renewcommand{\corresfirstargument}{#1}\gdef\@corres{#2}} 
\newcommand{\corres}[3][]{\renewcommand{\corresfirstargument}{#1}\gdef\@corresEmail{#2}\gdef\@corresAddress{#3}} 
\def\@conference{}
\newcommand{\conference}[1]{\gdef\@conference{#1}}%
\def\@abstract{}
\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}
\def\@externaleditor{}
\newcommand{\externaleditor}[1]{\gdef\@externaleditor{#1}}
\def\@LSID{}
\newcommand{\LSID}[1]{\gdef\@LSID{#1}}
\newcommand{\datereceived}[1]{\gdef\@datereceived{#1}} 
\newcommand{\dateaccepted}[1]{\gdef\@dateaccepted{#1}} 
\newcommand{\datepublished}[1]{\gdef\@datepublished{#1}} 
\def\@pacs{}
\newcommand{\PACS}[1]{\gdef\@pacs{#1}} 
\def\@msc{}
\newcommand{\MSC}[1]{\gdef\@msc{#1}} 
\def\@jel{}
\newcommand{\JEL}[1]{\gdef\@jel{#1}}
\def\@keyword{}
\newcommand{\keyword}[1]{\gdef\@keyword{#1}}
\def\@dataset{}
\newcommand{\dataset}[1]{\gdef\@dataset{#1}}
\def\@datasetlicense{}
\newcommand{\datasetlicense}[1]{\gdef\@datasetlicense{#1}}
\def\@featuredapplication{}
\newcommand{\featuredapplication}[1]{\gdef\@featuredapplication{#1}}
\def\@keycontribution{}
\newcommand{\keycontribution}[1]{\gdef\@keycontribution{#1}}
\def\@encyclopediadef{}
\newcommand{\encyclopediadef}[1]{\gdef\@encyclopediadef{#1}}
\def\@issuenum{}
\newcommand{\issuenum}[1]{\gdef\@issuenum{\cutdigits{#1}}}
\def\@firstnote{}
\newcommand{\firstnote}[1]{\gdef\@firstnote{#1}}
\def\@secondnote{}
\newcommand{\secondnote}[1]{\gdef\@secondnote{#1}}%
\def\@thirdnote{}
\newcommand{\thirdnote}[1]{\gdef\@thirdnote{#1}}%
\def\@fourthnote{}
\newcommand{\fourthnote}[1]{\gdef\@fourthnote{#1}}%
\def\@fifthnote{}
\newcommand{\fifthnote}[1]{\gdef\@fifthnote{#1}}%
\def\@sixthnote{}
\newcommand{\sixthnote}[1]{\gdef\@sixthnote{#1}}%
\def\@seventhnote{}
\newcommand{\seventhnote}[1]{\gdef\@seventhnote{#1}}%
\def\@eighthnote{}
\newcommand{\eighthnote}[1]{\gdef\@eighthnote{#1}}%
\def\@simplesumm{}
\newcommand{\simplesumm}[1]{\gdef\@simplesumm{#1}}
\newcommand{\articlenumber}[1]{
	\ifthenelse{\equal{\@journal}{molbank}}{
		\gdef\@articlenumber{#1}%
		}{
		\gdef\@articlenumber{\cutdigits{#1}}%
		}
	}

\def\@externalbibliography{}
\newcommand{\externalbibliography}[1]{\gdef\@externalbibliography{#1}}
\def\@reftitle{}
\newcommand{\reftitle}[1]{\gdef\@reftitle{#1}}


%% ORCID
% Make Orcid icon
\newcommand{\orcidicon}{\includegraphics[width=0.32cm]{IJMSA_logo/logo-orcid.pdf}}

% Define link and button for each author
\foreach \x in {A, ..., Z}{%
\expandafter\xdef\csname orcid\x\endcsname{\noexpand\href{https://orcid.org/\csname orcidauthor\x\endcsname}{\noexpand\orcidicon}}
}


%%%% Journal name for the header
\newcommand{\journalname}{\@journalshort}
    
\regtotcounter{page} % To enable extracting the value of the counter "page" using the totcount package


%%%% Header and footer on first page
%% The plain page style needs to be redefined because with \maketitle in the article class, LaTeX applies the the plain page style automatically to the first page.
\fancypagestyle{plain}{
	\renewcommand{\footrulewidth}{0.0pt}
	\fancyhead{\null\vspace{8pt}}
	\ifthenelse{\equal{\@arttype}{JASMAC}}{}{
	\fancyfoot[L]{
	\fontsize{8}{8}\selectfont
	\ifthenelse{\equal{\@status}{submit}}{%
		Version {\@ \today} submitted to {\em \journalname}%
		}{%
			{\em\journalname\ }{\bfseries\@pubvolume}{(\@issuenum)\ }{\em \@pubvolume\twodigits\@issuenum\twodigits\@articlenumber\ }{(\@pubyear)}; {\em doi:\ \@doinum} %
		}%
	}
    }
	\fancyfoot[R]{
		\fontsize{8}{8}\selectfont\thepage{} of \pageref*{LastPage}
	}
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Maketitle part 1: Logo, Arttype, Title, Author
\renewcommand{\@maketitle}{
%%	{\noindent\centering{\fontsize{8}{8}\selectfont {\bfseries Journal WEB site:} \@journalURL} \par}
	\noindent\ifthenelse{\equal{\@arttype}{Article}}{\includegraphics[width=\textwidth]{IJMSA_logo/IJMSA_header_OrigPaper.pdf}}{%
		\ifthenelse{\equal{\@arttype}{Review}}{\includegraphics[width=\textwidth]{IJMSA_logo/IJMSA_header_ReviewPaper.pdf}}{%
			\ifthenelse{\equal{\@arttype}{JASMAC}}{\includegraphics[width=\textwidth]{IJMSA_logo/JASMAC_header.pdf}}{}
		}
	}
	{%
		\fontsize{18}{18}\selectfont
		\hyphenpenalty=10000
		\tolerance=1000
		\boldmath\bfseries{\textcolor[rgb]{0.4078,0.164705,0.298039}{\@Title}}
		\par
		\vskip10pt
	}%
 	{%
		\fontsize{10}{10}\selectfont
		\hyphenpenalty=10000
		\tolerance=1000
    		\noindent\boldmath\bfseries{\@Author}
    		\par
		\vspace{-1pt}
    	}%
}

% Commands for hanging indent
\newcommand{\dist}{1.7em}
\newcommand{\hang}{\hangafter=1\hangindent=\dist\noindent}
\newcommand{\distT}{8.0em}
\newcommand{\hangT}{\hangafter=1\hangindent=\distT\noindent}

%%%% Maketitle part 2
\newcommand{\maketitlen}{ 
	\begin{flushleft}
	\begin{spacing}{1.35}
	\hyphenpenalty=10000
	\tolerance=1000
	\fontsize{9}{9}\selectfont
	{%
	\ifthenelse{\equal{\firstargument}{1}}{}{%
	\hang}\@address
	\par
	}%
	{%
	\ifthenelse{\equal{\@authornum}{author}}{}{%
	\ifthenelse{\equal{\@corresEmail}{\@empty}}{}{%
%%%	\hang\textbf{$^\ast$} \tabto{\dist} \@corres}
	\hang\textbf{$^\ast$}\, \@corresEmail \par \hang \hspace{3.0mm} {\fontsize{8.5pt}{0pt}\selectfont \@corresAddress}}
	\par
	}
	}%
	{%
	\ifthenelse{\equal{\@firstnote}{\@empty}}{}{%
	\hang\ifthenelse{\equal{\@conference}{\@empty}}{$\dagger$}{$\ddagger$} \tabto{\dist} \@firstnote}	
	\par
	}%
	{%
	\ifthenelse{\equal{\@secondnote}{\@empty}}{}{%
	\hang \ifthenelse{\equal{\@conference}{\@empty}}{$\ddagger$}{\S} \tabto{\dist} \@secondnote}
	\par
	}%
	{%
	\ifthenelse{\equal{\@thirdnote}{\@empty}}{}{%
	\hang \ifthenelse{\equal{\@conference}{\@empty}}{\S}{$\|$} \tabto{\dist} \@thirdnote}
	\par
	}%
	\end{spacing}
	\end{flushleft}
}

\definecolor{colAbstBack}{rgb}{0.9568627,0.92549019,0.83529411}
%%%% Abstract, keywords, journal data, PACS, MSC, JEL
\newcommand{\abstractkeywords}{
\fontsize{9}{12.4}\selectfont
\vspace{-8pt}
%10
\begin{tcolorbox}[boxrule=0pt,colback=colAbstBack,arc=0pt,outer arc=0pt,left=2mm,right=2mm,top=3pt,bottom=0pt]
\ifthenelse{\equal{\@abstract}{\@empty}}{}{
	\ifthenelse{\equal{\@graphicalAbstract}{\@empty}}%
	{
		\noindent\textbf{Abstract:\space}\@abstract
	}{
			\setlength{\columnsep}{0pt}
			\setlength{\intextsep}{0pt}
			\begin{wrapfigure}{r}{67mm}
			\raisebox{3mm}{\hspace*{5mm}\includegraphics[clip,width=65mm]{\@graphicalAbstract}}
			\end{wrapfigure}
			\noindent\textbf{Abstract:\space}\@abstract
	}
	}
\end{tcolorbox}
%
\begin{tcolorbox}[boxrule=0pt,colback=colAbstBack,arc=0pt,outer arc=0pt,left=2mm,right=2mm,top=3pt,bottom=0pt]
\ifthenelse{\equal{\@keyword}{\@empty}}{}{
	\noindent\textbf{Keywords:\space} \hangT \tabto{\distT}\@keyword
	\par
	}
	{
	\noindent\textbf{Article History:\space} \hangT \tabto{\distT} %
	Received: \@datereceived, 
	accepted: \@dateaccepted, 
	published: \@datepublished.
	}
\end{tcolorbox}
\normalsize
}


%%%% Print maketitle and abstractkeywords
	\AfterEndPreamble{
	\maketitle
	\let\maketitle\relax
	\maketitlen
	\let\maketitlen\relax
	\ifthenelse{\equal{\@status}{submit}}{\linenumbers}{}
	\ifthenelse{\equal{\@arttype}{JASMAC}}%
     {}%
     {\abstractkeywords}
}%

\AtBeginDocument{
	\DeclareSymbolFont{AMSb}{U}{msb}{m}{n}
	\DeclareSymbolFontAlphabet{\mathbb}{AMSb}
	}


%%%% Font size in Tables
\AtEndPreamble{
	\def\@tablesize{}
	\newcommand{\tablesize}[1]{\gdef\@tablesize{#1}}
	\let\oldtabularx\tabularx
	\renewcommand{\tabularx}{\ifthenelse{\equal{\@tablesize}{\@empty}}{\small}{\@tablesize}\oldtabularx}
}


%%%% Section headings
\setcounter{secnumdepth}{4} % Default: 3 in the article class. To get paragraphs numbered and counted, increase the default value of secnumdepth to 4

%%%\titleformat {\section} [block] {\raggedright \fontsize{10}{10}\selectfont\bfseries} {\thesection.\space} {0pt} {}
%%%\titlespacing {\section} {0pt} {12pt} {3pt}
%%%\titleformat {\subsection} [block] {\raggedright \fontsize{10}{10}\selectfont\itshape} {\thesubsection.\space} {0pt} {}
%%%\titlespacing {\subsection} {0pt} {12pt} {3pt}
%%%\titleformat {\subsubsection} [block] {\raggedright \fontsize{10}{10}\selectfont} {\thesubsubsection.\space} {0pt} {}
%%%\titlespacing {\subsubsection} {0pt} {12pt} {3pt}
%%%\titleformat {\paragraph} [block] {\raggedright \fontsize{10}{10}\selectfont} {} {0pt} {}
%%%\titlespacing {\paragraph} {0pt} {12pt} {6pt}

%%% [2021/07/11 Shiratori]
%%% \titleformat{hcommandi}[shape]{format}{label}{sep}{before-code}[after-code]
%%% \titlespacing{}{left}{before-sep}{after-sep}

%%% [2023/01/21 Shiatori  changed from block to hang]
%\titleformat {\section} [block] {\raggedright \fontsize{10}{10}\selectfont\bfseries} {\thesection.\space} {3pt} {}
\titleformat {\section} [hang] {\raggedright \fontsize{10}{10}\selectfont\bfseries} {\thesection.\space} {3pt} {}
\titlespacing {\section} {0pt} {12pt} {6pt}

%\titleformat {\subsection} [block] {\raggedright \fontsize{10}{10}\selectfont} {\thesubsection.\space} {3pt} {}
\titleformat {\subsection} [hang] {\raggedright \fontsize{10}{10}\selectfont} {\thesubsection.\space} {3pt} {}
\titlespacing {\subsection} {0pt} {12pt} {6pt}

%\titleformat {\subsubsection} [block] {\raggedright \fontsize{10}{10}\selectfont} {\thesubsubsection.\space} {3pt} {}
\titleformat {\subsubsection} [hang] {\raggedright \fontsize{10}{10}\selectfont} {\thesubsubsection.\space} {3pt} {}
\titlespacing {\subsubsection} {0pt} {12pt} {6pt}

%\titleformat {\paragraph} [block] {\raggedright \fontsize{10}{10}\selectfont} {} {3pt} {}
\titleformat {\paragraph} [hang] {\raggedright \fontsize{10}{10}\selectfont} {} {3pt} {}
\titlespacing {\paragraph} {0pt} {12pt} {6pt}




%%%%% Defines the appendix
\def\@appendixtitles{}
\newcommand{\appendixtitles}[1]{\gdef\@appendixtitles{#1}}

\def\@appendixsections{}
\newcommand{\appendixsections}[1]{\gdef\@appendixsections{#1}}

\def\@appendixstart{}
\newcommand{\appendixstart}[1]{\gdef\@appendixstart{#1}}

\renewcommand{\appendixstart}{%
\setcounter{section}{0}%
\setcounter{subsection}{0}%
\setcounter{subsubsection}{0}%
\setcounter{figure}{0}
\setcounter{specialtable}{0}
\setcounter{scheme}{0}
\setcounter{chart}{0}
\setcounter{boxenv}{0}
\setcounter{equation}{0}
\setcounter{theorem}{0}
\setcounter{lemma}{0}
\setcounter{corollary}{0}
\setcounter{proposition}{0} 
\setcounter{characterization}{0} 
\setcounter{property}{0} 
\setcounter{problem}{0} 
\setcounter{example}{0} 
\setcounter{examplesanddefinitions}{0} 
\setcounter{remark}{0} 
\setcounter{definition}{0} 
\setcounter{hypothesis}{0}
\setcounter{notation}{0}

}

\renewcommand{\appendix}{%
%
\gdef\thesection{\@Alph\c@section}%
\gdef\thesubsection{\@Alph\c@section.\@arabic\c@subsection}%
%	
\titleformat {\section} [block] {\raggedright\bfseries} {%
	\ifthenelse{\equal{\@appendixtitles}{yes}}{%
		\appendixname~\thesection.%
		}{%
		\appendixname~\thesection~%
		}
	} {0pt} {}
\titlespacing {\section} {0pt} {12pt} {3pt}
%
\titleformat {\subsection} [block] {\raggedright\itshape} {%
	\ifthenelse{\equal{\@appendixtitles}{yes}}{%
		\appendixname~\thesubsection.%
		}{%
		\appendixname~\thesubsection%
		}
	} {0pt} {}
\titlespacing {\section} {0pt} {12pt} {3pt}
%
\titleformat {\subsubsection} [block] {\raggedright\selectfont} {%
	\ifthenelse{\equal{\@appendixtitles}{yes}}{%
		\appendixname~\thesubsubsection.%
		}{%
		\appendixname~\thesubsubsection%
		}
	} {0pt} {}
\titlespacing {\section} {0pt} {12pt} {3pt}
%
\gdef\theHsection{\@Alph\c@section.}% for hyperref
\gdef\theHsubsection{\@Alph\c@section.\@arabic\c@subsection}% for hyperref
\csname appendixmore\endcsname
\renewcommand{\thefigure}{A\arabic{figure}}
\renewcommand{\thespecialtable}{A\arabic{specialtable}}
\renewcommand{\thescheme}{A\arabic{scheme}}
\renewcommand{\thechart}{A\arabic{chart}}
\renewcommand{\theboxenv}{A\arabic{boxenv}}
\renewcommand{\theequation}{A\arabic{equation}}
\renewcommand{\thetheorem}{A\arabic{theorem}}
\renewcommand{\thelemma}{A\arabic{lemma}}
\renewcommand{\thecorollary}{A\arabic{corollary}}
\renewcommand{\theproposition}{A\arabic{proposition}} 
\renewcommand{\thecharacterization}{A\arabic{characterization}}
\renewcommand{\theproperty}{A\arabic{property}}
\renewcommand{\theproblem}{A\arabic{problem}}
\renewcommand{\theexample}{A\arabic{example}}
\renewcommand{\theexamplesanddefinitions}{A\arabic{examplesanddefinitions}}
\renewcommand{\theremark}{A\arabic{remark}}
\renewcommand{\thedefinition}{A\arabic{definition}}
\renewcommand{\thehypothesis}{A\arabic{hypothesis}}
\renewcommand{\thenotation}{A\arabic{notation}}
}


%%%% Layout
\RequirePackage[%
	left=20mm,
	right=20mm,
	top=15mm,
	bottom=20mm,
	footskip=16pt,
	headsep=0pt
%	includehead,
%	includefoot
]{geometry}


\linespread{1.05} 
\setlength{\parindent}{0.75cm}
\ifthenelse{\equal{\@status}{submit}}{\setlength{\columnsep}{1cm}}{\setlength{\columnsep}{0.5cm}} % Distance between the two columns on the first page

%%%% Commands for landscape page
\newcommand{\startlandscape}{
	\clearpage
	\paperwidth=\pdfpageheight
	\paperheight=\pdfpagewidth
	\pdfpageheight=\paperheight
	\pdfpagewidth=\paperwidth
	\newgeometry{layoutwidth=297mm,layoutheight=210 mm, left=1.27cm,right=1.27cm,top=1.8cm,bottom=0.6cm, includehead,includefoot}
	\fancyheadoffset{0pt}
}

\newcommand{\finishlandscape}{
	\clearpage
	\paperwidth=\pdfpageheight
	\paperheight=\pdfpagewidth
	\pdfpageheight=\paperheight
	\pdfpagewidth=\paperwidth
	\restoregeometry
	\ifthenelse{\equal{\@status}{submit}}{\linenumbers}{}
}


%%%% Figures and tables
\RequirePackage{newfloat}
\DeclareFloatingEnvironment[]{listing}
\DeclareFloatingEnvironment[name=Box]{boxenv}	
\DeclareFloatingEnvironment[]{chart}
\DeclareFloatingEnvironment[]{scheme}
\DeclareFloatingEnvironment[]{figurewide}
\DeclareFloatingEnvironment[name=Table]{specialtable}

\RequirePackage{caption} 
\captionsetup[figure]{format=hang, position=bottom,labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, belowskip=-6pt, singlelinecheck=on, justification=justified}

\captionsetup[scheme]{format=hang, position=bottom,labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, belowskip=-6pt, singlelinecheck=off, justification=justified}

\captionsetup[listing]{format=hang, position=top, labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, singlelinecheck=off, justification=justified}

\captionsetup[chart]{format=hang, position=bottom, labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, belowskip=-6pt, singlelinecheck=off, justification=justified}

\captionsetup[table]{format=hang, position=top, labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, singlelinecheck=on, justification=justified}

\captionsetup[specialtable]{format=hang, position=top, labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, singlelinecheck=on, justification=justified}

\captionsetup[boxenv]{format=hang, position=top, labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, singlelinecheck=off, justification=justified}


\newcommand{\widefigure}{\captionsetup{position=bottom, margin=0.75cm, labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, belowskip=-6pt, singlelinecheck=on, justification=justified}
\centering
}

\newcommand{\widetable}{\captionsetup{position=top, margin=0.75cm, labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, singlelinecheck=on, justification=justified}
\centering
}


%% Link to supplementary material: www.jstage.jst.go.jp/browse/ijmsa/volume-number/issue-number/article-number	
\newcommand{\linksupplementary}[1]{\url{\@journalURL/\@pubvolume/\@issuenum/\@articlenumber/Suppl/#1}}


%% For table footnotes
\newsavebox{\@justcentbox}
\newcommand{\justifyorcenter}[1]{
\sbox \@justcentbox{#1}
\ifdim \wd \@justcentbox >\hsize #1
\else \centerline{#1} \fi
}


%%%% Bullet lists
\setitemize{topsep=3pt,parsep=0pt,itemsep=0pt,leftmargin=*,labelsep=5.5mm,align=parleft}
\setenumerate{topsep=3pt,parsep=0pt,itemsep=0pt,leftmargin=*,labelsep=5.5mm,align=parleft}
\setlist[description]{itemsep=0mm}


%%%% Quote environment
\renewenvironment{quote}{
	\list{}{
		\listparindent=0pt
		\leftmargin=0.75cm
		\rightmargin=0.75cm
		\topsep=3pt
		\parsep=3pt
	}%
	\item\relax
	}
	{\endlist}



%%%% Header and footer (all pages except the first)
\renewcommand\headrule{} %% set line (from fancyhdr) in header to nothing

\pagestyle{fancy}
\lhead{}
\rhead{}
\lfoot{
	\ifthenelse{\equal{\@arttype}{JASMAC}}
	{\em Proceedings of the JASMAC}
	{
	\fontsize{8}{8}\selectfont
	\ifthenelse{\equal{\@status}{submit}}{%
		Version {\@ \today} submitted to {\em \journalname}%
		}{%
		{\em\journalname\ }{\bfseries\@pubvolume}{(\@issuenum)\ }{\em \@pubvolume\twodigits\@issuenum\twodigits\@articlenumber\ }{(\@pubyear)}%
	}%
}
}
	
\rfoot{\fontsize{8}{8}\selectfont\thepage{} of \pageref*{LastPage}}
\cfoot{}



%%%% Bibliography
\renewcommand\bibname{References} % Backwards compatibility for book production
\renewcommand\@biblabel[1]{#1.\hfill}
\def\thebibliography#1{
\emergencystretch 2em
\section*{\@reftitle}
\addcontentsline{toc}{section}{References}
\fontsize{9}{11}\selectfont
\list{{\arabic{enumi}}}{\def\makelabel##1{\hss{##1}}
\topsep=0\p@
\parsep=0\p@
\partopsep=0\p@
\itemsep=0\p@
\labelsep=1.5mm
	\itemindent=0\p@
\settowidth\labelwidth{\footnotesize[#1]}%
\leftmargin\labelwidth
\advance\leftmargin\labelsep
%\advance\leftmargin -\itemindent
\usecounter{enumi}}
%\def\newblock{\ }
%\sloppy\clubpenalty4000\widowpenalty4000
%\sfcode`\.=1000\relax
}
\let\endthebibliography=\endlist


%%%% Copyright info
\newcommand{\cright}{%
	\par\vspace{1em}
	\ifthenelse{\equal{\@status}{submit}}{%
		\fontsize{9}{9}\selectfont
		\copyright{} {\@ \the\year} by the \@authornum. %
		Submitted to {\em \journalname} for possible open access publication under the terms and conditions of the Creative Commons Attribution (CC BY)license %
		\changeurlcolor{black} (https://\href{https://creativecommons.org/licenses/by/4.0/}{creativecommons.org/licenses/by/} 4.0/).
	}{%
		\begin{minipage}{27.8mm}
		\href{https://creativecommons.org/}{\includegraphics[width=27.8mm]{IJMSA_logo/logo-ccby.pdf}} 
		\end{minipage} \hfill
		\begin{minipage}{130mm}
		{\fontsize{9}{9}\selectfont
		\copyright \ {\@copyrightyear} by the \@authornum. %
		This article is an open access article distributed under the terms and conditions of the Creative Commons Attribution (CC BY) license %
		\changeurlcolor{black} (https://\href{https://creativecommons.org/licenses/by/4.0/}{creativecommons.org/licenses/by/} 4.0/).
		}
		\end{minipage}
	}
}
	
%%%% For tables XML2PDF
\RequirePackage{seqsplit} % Use for split table column
  \newlength{\cellWidtha}
  \newlength{\cellWidthb}
  \newlength{\cellWidthc}
  \newlength{\cellWidthd}
  \newlength{\cellWidthe}
  \newlength{\cellWidthf}
  \newlength{\cellWidthg}
  \newlength{\cellWidthh}
  \newlength{\cellWidthi}
  \newlength{\cellWidthj}
  \newlength{\cellWidthk}
  \newlength{\cellWidthl}
  \newlength{\cellWidthm}
  \newlength{\cellWidthn}
  \newlength{\cellWidtho}
  \newlength{\cellWidthp}
  \newlength{\cellWidthq}
  \newlength{\cellWidthr}
  \newlength{\cellWidths}
  \newlength{\cellWidtht}
  \newlength{\cellWidthu}
  \newlength{\cellWidthv}
  \newlength{\cellWidthw}
  \newlength{\cellWidthx}
  \newlength{\cellWidthy}
  \newlength{\cellWidthz}
  \newlength{\cellWidthA}
  \newlength{\cellWidthB}
  \newlength{\cellWidthC}
  \newlength{\cellWidthD}
  \newlength{\cellWidthE}
  \newlength{\cellWidthF}
  \newlength{\cellWidthG}
  \newlength{\cellWidthH}
  \newlength{\cellWidthI}
  \newlength{\cellWidthJ}
  \newlength{\cellWidthK}
  \newlength{\cellWidthL}
  \newlength{\cellWidthM}
  \newlength{\cellWidthN}
  \newlength{\cellWidthO}
  \newlength{\cellWidthP}
  \newlength{\cellWidthQ}
  \newlength{\cellWidthR}
  \newlength{\cellWidthS}
  \newlength{\cellWidthT}
  \newlength{\cellWidthU}
  \newlength{\cellWidthV}
  \newlength{\cellWidthW}
  \newlength{\cellWidthX}
  \newlength{\cellWidthY}
  \newlength{\cellWidthZ}
 \newcommand{\PreserveBackslash}[1]{\let\temp=\\#1\let\\=\temp} % For table column setting in XML2PDF

\endinput
